pub struct executeOutputCall {
pub output: Bytes,
pub proof: <OutputValidityProof as SolType>::RustType,
}Expand description
Function with signature executeOutput(bytes,(uint64,bytes32[])) and selector 0x33137b76.
function executeOutput(bytes memory output, OutputValidityProof memory proof) external;Fields
output: Bytesproof: <OutputValidityProof as SolType>::RustTypeTrait Implementations
Sourceimpl Clone for executeOutputCall
impl Clone for executeOutputCall
Sourcefn clone(&self) -> executeOutputCall
fn clone(&self) -> executeOutputCall
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for executeOutputCall
impl Debug for executeOutputCall
Sourceimpl Default for executeOutputCall
impl Default for executeOutputCall
Sourcefn default() -> executeOutputCall
fn default() -> executeOutputCall
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for executeOutputCall
impl<'de> Deserialize<'de> for executeOutputCall
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for executeOutputCall
impl Hash for executeOutputCall
Sourceimpl PartialEq for executeOutputCall
impl PartialEq for executeOutputCall
Sourceimpl Serialize for executeOutputCall
impl Serialize for executeOutputCall
Sourceimpl SolCall for executeOutputCall
impl SolCall for executeOutputCall
Sourceconst SIGNATURE: &'static str = "executeOutput(bytes,(uint64,bytes32[]))"
const SIGNATURE: &'static str = "executeOutput(bytes,(uint64,bytes32[]))"
The function’s ABI signature.
Sourcetype Parameters<'a> = (Bytes, OutputValidityProof)
type Parameters<'a> = (Bytes, OutputValidityProof)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<executeOutputCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<executeOutputCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding TokenSeq type.
Sourcetype Return = executeOutputReturn
type Return = executeOutputReturn
The function’s return struct.
Sourcetype ReturnTuple<'a> = ()
type ReturnTuple<'a> = ()
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<executeOutputCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<executeOutputCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding TokenSeq type.
Sourcefn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
fn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize_returns(ret: &Self::Return) -> Self::ReturnToken<'_>
fn tokenize_returns(ret: &Self::Return) -> Self::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(data: &[u8]) -> Result<Self::Return>
fn abi_decode_returns(data: &[u8]) -> Result<Self::Return>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(data: &[u8]) -> Result<Self::Return>
fn abi_decode_returns_validate(data: &[u8]) -> Result<Self::Return>
ABI decode this call’s return values from the given slice, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
Sourcefn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
fn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
ABI encode the call’s return values.
impl Eq for executeOutputCall
impl StructuralPartialEq for executeOutputCall