pub struct getDeploymentBlockNumberReturn {
pub _0: U256,
}Expand description
Container type for the return parameters of the getDeploymentBlockNumber() function.
Fields
_0: U256Trait Implementations
Sourceimpl Clone for getDeploymentBlockNumberReturn
impl Clone for getDeploymentBlockNumberReturn
Sourcefn clone(&self) -> getDeploymentBlockNumberReturn
fn clone(&self) -> getDeploymentBlockNumberReturn
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for getDeploymentBlockNumberReturn
impl Default for getDeploymentBlockNumberReturn
Sourcefn default() -> getDeploymentBlockNumberReturn
fn default() -> getDeploymentBlockNumberReturn
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for getDeploymentBlockNumberReturn
impl<'de> Deserialize<'de> for getDeploymentBlockNumberReturn
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for getDeploymentBlockNumberReturn
impl PartialEq for getDeploymentBlockNumberReturn
Sourcefn eq(&self, other: &getDeploymentBlockNumberReturn) -> bool
fn eq(&self, other: &getDeploymentBlockNumberReturn) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for getDeploymentBlockNumberReturn
impl StructuralPartialEq for getDeploymentBlockNumberReturn