pub struct getNumberOfExecutedOutputsReturn {
pub _0: U256,
}Expand description
Container type for the return parameters of the getNumberOfExecutedOutputs() function.
Fields
_0: U256Trait Implementations
Sourceimpl Clone for getNumberOfExecutedOutputsReturn
impl Clone for getNumberOfExecutedOutputsReturn
Sourcefn clone(&self) -> getNumberOfExecutedOutputsReturn
fn clone(&self) -> getNumberOfExecutedOutputsReturn
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for getNumberOfExecutedOutputsReturn
impl Default for getNumberOfExecutedOutputsReturn
Sourcefn default() -> getNumberOfExecutedOutputsReturn
fn default() -> getNumberOfExecutedOutputsReturn
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for getNumberOfExecutedOutputsReturn
impl<'de> Deserialize<'de> for getNumberOfExecutedOutputsReturn
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for getNumberOfExecutedOutputsReturn
impl PartialEq for getNumberOfExecutedOutputsReturn
Sourcefn eq(&self, other: &getNumberOfExecutedOutputsReturn) -> bool
fn eq(&self, other: &getNumberOfExecutedOutputsReturn) -> bool
Tests for
self and other values to be equal, and is used by ==.impl Eq for getNumberOfExecutedOutputsReturn
impl StructuralPartialEq for getNumberOfExecutedOutputsReturn