pub struct validateOutputHashCall {
pub outputHash: FixedBytes<32>,
pub proof: <OutputValidityProof as SolType>::RustType,
}Expand description
Function with signature validateOutputHash(bytes32,(uint64,bytes32[])) and selector 0x08eb89ab.
function validateOutputHash(bytes32 outputHash, OutputValidityProof memory proof) external view;Fields
outputHash: FixedBytes<32>proof: <OutputValidityProof as SolType>::RustTypeTrait Implementations
Sourceimpl Clone for validateOutputHashCall
impl Clone for validateOutputHashCall
Sourcefn clone(&self) -> validateOutputHashCall
fn clone(&self) -> validateOutputHashCall
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for validateOutputHashCall
impl Debug for validateOutputHashCall
Sourceimpl Default for validateOutputHashCall
impl Default for validateOutputHashCall
Sourcefn default() -> validateOutputHashCall
fn default() -> validateOutputHashCall
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for validateOutputHashCall
impl<'de> Deserialize<'de> for validateOutputHashCall
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for validateOutputHashCall
impl Hash for validateOutputHashCall
Sourceimpl PartialEq for validateOutputHashCall
impl PartialEq for validateOutputHashCall
Sourceimpl Serialize for validateOutputHashCall
impl Serialize for validateOutputHashCall
Sourceimpl SolCall for validateOutputHashCall
impl SolCall for validateOutputHashCall
Sourceconst SIGNATURE: &'static str = "validateOutputHash(bytes32,(uint64,bytes32[]))"
const SIGNATURE: &'static str = "validateOutputHash(bytes32,(uint64,bytes32[]))"
The function’s ABI signature.
Sourcetype Parameters<'a> = (FixedBytes<32>, OutputValidityProof)
type Parameters<'a> = (FixedBytes<32>, OutputValidityProof)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<validateOutputHashCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<validateOutputHashCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding TokenSeq type.
Sourcetype Return = validateOutputHashReturn
type Return = validateOutputHashReturn
The function’s return struct.
Sourcetype ReturnTuple<'a> = ()
type ReturnTuple<'a> = ()
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<validateOutputHashCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<validateOutputHashCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding TokenSeq type.
Sourcefn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
fn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize_returns(ret: &Self::Return) -> Self::ReturnToken<'_>
fn tokenize_returns(ret: &Self::Return) -> Self::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(data: &[u8]) -> Result<Self::Return>
fn abi_decode_returns(data: &[u8]) -> Result<Self::Return>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(data: &[u8]) -> Result<Self::Return>
fn abi_decode_returns_validate(data: &[u8]) -> Result<Self::Return>
ABI decode this call’s return values from the given slice, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
Sourcefn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
fn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
ABI encode the call’s return values.
impl Eq for validateOutputHashCall
impl StructuralPartialEq for validateOutputHashCall