pub struct OutputNotExecutable {
pub output: Bytes,
}Expand description
Custom error with signature OutputNotExecutable(bytes) and selector 0xd284c01e.
error OutputNotExecutable(bytes output);Fields
output: BytesTrait Implementations
Sourceimpl Clone for OutputNotExecutable
impl Clone for OutputNotExecutable
Sourcefn clone(&self) -> OutputNotExecutable
fn clone(&self) -> OutputNotExecutable
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for OutputNotExecutable
impl Debug for OutputNotExecutable
Sourceimpl Default for OutputNotExecutable
impl Default for OutputNotExecutable
Sourcefn default() -> OutputNotExecutable
fn default() -> OutputNotExecutable
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for OutputNotExecutable
impl<'de> Deserialize<'de> for OutputNotExecutable
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for OutputNotExecutable
impl Hash for OutputNotExecutable
Sourceimpl PartialEq for OutputNotExecutable
impl PartialEq for OutputNotExecutable
Sourceimpl Serialize for OutputNotExecutable
impl Serialize for OutputNotExecutable
Sourceimpl SolError for OutputNotExecutable
impl SolError for OutputNotExecutable
Sourcetype Parameters<'a> = (Bytes,)
type Parameters<'a> = (Bytes,)
The underlying tuple type which represents the error’s members. Read more
Sourcetype Token<'a> = <<OutputNotExecutable as SolError>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<OutputNotExecutable as SolError>::Parameters<'a> as SolType>::Token<'a>
The corresponding
TokenSeq type.Sourcefn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
fn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize(&self) -> Self::Token<'_>
fn tokenize(&self) -> Self::Token<'_>
Convert to the token type used for EIP-712 encoding and decoding.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self>
ABI decode this error’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the error params when encoded in bytes, without the
selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this error’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this error’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the error to the given buffer without its selector.
impl Eq for OutputNotExecutable
impl StructuralPartialEq for OutputNotExecutable