pub struct OutputNotReexecutable {
pub output: Bytes,
}Expand description
Custom error with signature OutputNotReexecutable(bytes) and selector 0x7b97a6bb.
error OutputNotReexecutable(bytes output);Fields
output: BytesTrait Implementations
Sourceimpl Clone for OutputNotReexecutable
impl Clone for OutputNotReexecutable
Sourcefn clone(&self) -> OutputNotReexecutable
fn clone(&self) -> OutputNotReexecutable
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for OutputNotReexecutable
impl Debug for OutputNotReexecutable
Sourceimpl Default for OutputNotReexecutable
impl Default for OutputNotReexecutable
Sourcefn default() -> OutputNotReexecutable
fn default() -> OutputNotReexecutable
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for OutputNotReexecutable
impl<'de> Deserialize<'de> for OutputNotReexecutable
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for OutputNotReexecutable
impl Hash for OutputNotReexecutable
Sourceimpl PartialEq for OutputNotReexecutable
impl PartialEq for OutputNotReexecutable
Sourceimpl Serialize for OutputNotReexecutable
impl Serialize for OutputNotReexecutable
Sourceimpl SolError for OutputNotReexecutable
impl SolError for OutputNotReexecutable
Sourcetype Parameters<'a> = (Bytes,)
type Parameters<'a> = (Bytes,)
The underlying tuple type which represents the error’s members. Read more
Sourcetype Token<'a> = <<OutputNotReexecutable as SolError>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<OutputNotReexecutable as SolError>::Parameters<'a> as SolType>::Token<'a>
The corresponding
TokenSeq type.Sourcefn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
fn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize(&self) -> Self::Token<'_>
fn tokenize(&self) -> Self::Token<'_>
Convert to the token type used for EIP-712 encoding and decoding.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self>
ABI decode this error’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the error params when encoded in bytes, without the
selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this error’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this error’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the error to the given buffer without its selector.
impl Eq for OutputNotReexecutable
impl StructuralPartialEq for OutputNotReexecutable