pub struct InputTooLarge {
pub appContract: Address,
pub inputLength: U256,
pub maxInputLength: U256,
}Expand description
Custom error with signature InputTooLarge(address,uint256,uint256) and selector 0x9f21b8a0.
error InputTooLarge(address appContract, uint256 inputLength, uint256 maxInputLength);Fields
appContract: AddressinputLength: U256maxInputLength: U256Trait Implementations
Sourceimpl Clone for InputTooLarge
impl Clone for InputTooLarge
Sourcefn clone(&self) -> InputTooLarge
fn clone(&self) -> InputTooLarge
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for InputTooLarge
impl Debug for InputTooLarge
Sourceimpl Default for InputTooLarge
impl Default for InputTooLarge
Sourcefn default() -> InputTooLarge
fn default() -> InputTooLarge
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for InputTooLarge
impl<'de> Deserialize<'de> for InputTooLarge
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for InputTooLarge
impl Hash for InputTooLarge
Sourceimpl PartialEq for InputTooLarge
impl PartialEq for InputTooLarge
Sourceimpl Serialize for InputTooLarge
impl Serialize for InputTooLarge
Sourceimpl SolError for InputTooLarge
impl SolError for InputTooLarge
Sourceconst SIGNATURE: &'static str = "InputTooLarge(address,uint256,uint256)"
const SIGNATURE: &'static str = "InputTooLarge(address,uint256,uint256)"
The error’s ABI signature.
Sourcetype Parameters<'a> = (Address, Uint<256>, Uint<256>)
type Parameters<'a> = (Address, Uint<256>, Uint<256>)
The underlying tuple type which represents the error’s members. Read more
Sourcetype Token<'a> = <<InputTooLarge as SolError>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<InputTooLarge as SolError>::Parameters<'a> as SolType>::Token<'a>
The corresponding
TokenSeq type.Sourcefn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
fn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize(&self) -> Self::Token<'_>
fn tokenize(&self) -> Self::Token<'_>
Convert to the token type used for EIP-712 encoding and decoding.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self>
ABI decode this error’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the error params when encoded in bytes, without the
selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this error’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this error’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the error to the given buffer without its selector.
impl Eq for InputTooLarge
impl StructuralPartialEq for InputTooLarge