pub struct getInputHashCall {
pub appContract: Address,
pub index: U256,
}Expand description
Function with signature getInputHash(address,uint256) and selector 0x677087c9.
function getInputHash(address appContract, uint256 index) external view returns (bytes32);Fields
appContract: Addressindex: U256Trait Implementations
Sourceimpl Clone for getInputHashCall
impl Clone for getInputHashCall
Sourcefn clone(&self) -> getInputHashCall
fn clone(&self) -> getInputHashCall
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for getInputHashCall
impl Debug for getInputHashCall
Sourceimpl Default for getInputHashCall
impl Default for getInputHashCall
Sourcefn default() -> getInputHashCall
fn default() -> getInputHashCall
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for getInputHashCall
impl<'de> Deserialize<'de> for getInputHashCall
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for getInputHashCall
impl Hash for getInputHashCall
Sourceimpl PartialEq for getInputHashCall
impl PartialEq for getInputHashCall
Sourceimpl Serialize for getInputHashCall
impl Serialize for getInputHashCall
Sourceimpl SolCall for getInputHashCall
impl SolCall for getInputHashCall
Sourcetype Parameters<'a> = (Address, Uint<256>)
type Parameters<'a> = (Address, Uint<256>)
The underlying tuple type which represents this type’s arguments. Read more
Sourcetype Token<'a> = <<getInputHashCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<getInputHashCall as SolCall>::Parameters<'a> as SolType>::Token<'a>
The arguments’ corresponding TokenSeq type.
Sourcetype Return = FixedBytes<32>
type Return = FixedBytes<32>
The function’s return struct.
Sourcetype ReturnTuple<'a> = (FixedBytes<32>,)
type ReturnTuple<'a> = (FixedBytes<32>,)
The underlying tuple type which represents this type’s return values. Read more
Sourcetype ReturnToken<'a> = <<getInputHashCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
type ReturnToken<'a> = <<getInputHashCall as SolCall>::ReturnTuple<'a> as SolType>::Token<'a>
The returns’ corresponding TokenSeq type.
Sourcefn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
fn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize_returns(ret: &Self::Return) -> Self::ReturnToken<'_>
fn tokenize_returns(ret: &Self::Return) -> Self::ReturnToken<'_>
Tokenize the call’s return values.
Sourcefn abi_decode_returns(data: &[u8]) -> Result<Self::Return>
fn abi_decode_returns(data: &[u8]) -> Result<Self::Return>
ABI decode this call’s return values from the given slice.
Sourcefn abi_decode_returns_validate(data: &[u8]) -> Result<Self::Return>
fn abi_decode_returns_validate(data: &[u8]) -> Result<Self::Return>
ABI decode this call’s return values from the given slice, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the encoded data in bytes, without its selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the call to the given buffer without its selector.
Sourcefn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
fn abi_encode_returns_tuple<'a, E>(e: &'a E) -> Vec<u8> ⓘwhere
E: SolTypeValue<Self::ReturnTuple<'a>>,
ABI encode the call’s return values.
impl Eq for getInputHashCall
impl StructuralPartialEq for getInputHashCall