Generated by the following Solidity interface…
interface LibAddressArray {}…which was generated by the following JSON ABI:
[]Structs
- LibAddress
Array Instance - A
LibAddressArrayinstance.
Statics
- BYTECODE
- The creation / init bytecode of the contract.
- DEPLOYED_
BYTECODE - The runtime bytecode of the contract, as deployed on the network.
Functions
- deploy
- Deploys this contract using the given
providerand constructor arguments, if any. - deploy_
builder - Creates a
RawCallBuilderfor deploying this contract using the givenproviderand constructor arguments, if any. - new
- Creates a new wrapper around an on-chain
LibAddressArraycontract instance.