pub struct StringsInvalidAddressFormat;Expand description
Custom error with signature StringsInvalidAddressFormat() and selector 0x1d15ae44.
error StringsInvalidAddressFormat();Trait Implementations
Sourceimpl Clone for StringsInvalidAddressFormat
impl Clone for StringsInvalidAddressFormat
Sourcefn clone(&self) -> StringsInvalidAddressFormat
fn clone(&self) -> StringsInvalidAddressFormat
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for StringsInvalidAddressFormat
impl Debug for StringsInvalidAddressFormat
Sourceimpl Default for StringsInvalidAddressFormat
impl Default for StringsInvalidAddressFormat
Sourcefn default() -> StringsInvalidAddressFormat
fn default() -> StringsInvalidAddressFormat
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for StringsInvalidAddressFormat
impl<'de> Deserialize<'de> for StringsInvalidAddressFormat
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl Hash for StringsInvalidAddressFormat
impl Hash for StringsInvalidAddressFormat
Sourceimpl SolError for StringsInvalidAddressFormat
impl SolError for StringsInvalidAddressFormat
Sourcetype Parameters<'a> = ()
type Parameters<'a> = ()
The underlying tuple type which represents the error’s members. Read more
Sourcetype Token<'a> = <<StringsInvalidAddressFormat as SolError>::Parameters<'a> as SolType>::Token<'a>
type Token<'a> = <<StringsInvalidAddressFormat as SolError>::Parameters<'a> as SolType>::Token<'a>
The corresponding
TokenSeq type.Sourcefn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
fn new<'a>(tuple: <Self::Parameters<'a> as SolType>::RustType) -> Self
Convert from the tuple type used for ABI encoding and decoding.
Sourcefn tokenize(&self) -> Self::Token<'_>
fn tokenize(&self) -> Self::Token<'_>
Convert to the token type used for EIP-712 encoding and decoding.
Sourcefn abi_decode_raw_validate(data: &[u8]) -> Result<Self>
fn abi_decode_raw_validate(data: &[u8]) -> Result<Self>
ABI decode this error’s arguments from the given slice, without its
selector, with validation. Read more
Sourcefn abi_encoded_size(&self) -> usize
fn abi_encoded_size(&self) -> usize
The size of the error params when encoded in bytes, without the
selector.
Sourcefn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
fn abi_decode_raw(data: &[u8]) -> Result<Self, Error>
ABI decode this call’s arguments from the given slice, without its
selector.
Sourcefn abi_decode(data: &[u8]) -> Result<Self, Error>
fn abi_decode(data: &[u8]) -> Result<Self, Error>
ABI decode this error’s arguments from the given slice, with the
selector.
Sourcefn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
fn abi_decode_validate(data: &[u8]) -> Result<Self, Error>
ABI decode this error’s arguments from the given slice, with the
selector, with validation. Read more
Sourcefn abi_encode_raw(&self, out: &mut Vec<u8>)
fn abi_encode_raw(&self, out: &mut Vec<u8>)
ABI encode the error to the given buffer without its selector.
impl Eq for StringsInvalidAddressFormat
impl StructuralPartialEq for StringsInvalidAddressFormat